SvgaAudioBackend class abstract interface

Plug in any audio engine (audioplayers, just_audio, a native channel…). The core package stays dependency-free.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTrack(String key, Uint8List bytes) → Future<SvgaAudioTrack>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited