Process-wide settings. Configure once at startup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- diskCacheDirectory ↔ String?
-
Directory for the raw
.svgadisk cache (e.g. from path_provider'sgetTemporaryDirectory()).nulldisables disk caching.getter/setter pair - maxConcurrentLoads ↔ int
-
Maximum concurrent uncached loads, including parsing and image decoding.
getter/setter pair
- networkTimeout ↔ Duration
-
Network timeout for the built-in downloader.
getter/setter pair